discard

package
v0.0.0-...-c4fd10a Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Sep 14, 2018 License: Apache-2.0 Imports: 2 Imported by: 4

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func Range

func Range(src *parse.Source, target []byte) int

Range discard the bytes until found one not matching the range table it returns how many bytes it discard

func Space

func Space(src *parse.Source) int

Space reads consecutive space(\t \n \v \f \r ' ') and returns the space number

func UnicodeRange

func UnicodeRange(src *parse.Source, table *unicode.RangeTable) int

UnicodeRange discard the runes until found one not matching the range table

func UnicodeRanges

func UnicodeRanges(src *parse.Source, includes []*unicode.RangeTable, excludes []*unicode.RangeTable) int

UnicodeRanges discard the runes until found one not matching the range tables

func UnicodeSpace

func UnicodeSpace(src *parse.Source) int

UnicodeSpace discard unicode spaces

Types

This section is empty.

Jump to